@@ -65,4 +65,8 @@ PYBIND11_MODULE(python_example_wierdre, m) {
     m.def("subtract", &subtract, "subtract function");
     m.def("multiply", &multiply, "multiply function");
     m.def("divide", &divide, "divide function");
+
+    m.def("arrinput", &arrinput, "input value into array");
+    m.def("arrdelete", &arrdelete, "delete value from array");
+    m.def("getvalue", &getvalue, "get value from array");
 }
\ No newline at end of file
